Additional API
~~~~~~~~~~~~~~
.. automodapi:: eazy.utils
    :no-inheritance-diagram:

.. automodapi:: eazy.sps
    :no-inheritance-diagram:

.. automodapi:: eazy.hdf5
    :no-inheritance-diagram:

.. automodapi:: eazy.visualization
    :no-inheritance-diagram:


